@@ -44,17 +44,17 @@ Accel::~Accel()
 }
 void Accel::setTarget( TQObject *target )
 {
-	connectItem( "Board Down" , target, TQT_SIGNAL( board_down() ) );
-	connectItem( "Board Up" , target, TQT_SIGNAL( board_up() ) );
-	connectItem( "Previous Move" , target, TQT_SIGNAL( move_prev() ) );
-	connectItem( "Next Move" , target, TQT_SIGNAL( move_next() ) );
-	connectItem( "Page Up", target, TQT_SIGNAL( page_up() ) );
-	connectItem( "Page Down", target, TQT_SIGNAL( page_down() ) );
-	connectItem( "Last History Item", target, TQT_SIGNAL( history_prev() ) );
-	connectItem( "Next History Item", target, TQT_SIGNAL( history_next() ) );
-	connectItem( "Tell Reply", target, TQT_SIGNAL( reply_tell() ) );
-	connectItem( "Channel Reply", target, TQT_SIGNAL( reply_channel() ) );
-	connectItem( "Enter Text", target, TQT_SIGNAL( focus() ) );
-	connectItem( "Kibitz", target, TQT_SIGNAL( kibitz() ) );
-	connectItem( "Whisper", target, TQT_SIGNAL( whisper() ) );
+	connectItem( "Board Down" , target, TQ_SIGNAL( board_down() ) );
+	connectItem( "Board Up" , target, TQ_SIGNAL( board_up() ) );
+	connectItem( "Previous Move" , target, TQ_SIGNAL( move_prev() ) );
+	connectItem( "Next Move" , target, TQ_SIGNAL( move_next() ) );
+	connectItem( "Page Up", target, TQ_SIGNAL( page_up() ) );
+	connectItem( "Page Down", target, TQ_SIGNAL( page_down() ) );
+	connectItem( "Last History Item", target, TQ_SIGNAL( history_prev() ) );
+	connectItem( "Next History Item", target, TQ_SIGNAL( history_next() ) );
+	connectItem( "Tell Reply", target, TQ_SIGNAL( reply_tell() ) );
+	connectItem( "Channel Reply", target, TQ_SIGNAL( reply_channel() ) );
+	connectItem( "Enter Text", target, TQ_SIGNAL( focus() ) );
+	connectItem( "Kibitz", target, TQ_SIGNAL( kibitz() ) );
+	connectItem( "Whisper", target, TQ_SIGNAL( whisper() ) );
 }
