@@ -31,7 +31,7 @@ class logic;
 
 class board_base : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public: 
