@@ -47,8 +47,8 @@ core::core(TQWidget *parent, const char *name, resource *Rsrc ) : TQWidget(paren
 
   myButtonGroup = new thinbuttons( this, "ButtonGroup", myResource );
   myButtonGroup->show();
-  connect( myButtonGroup, TQT_SIGNAL( leftClick(int) ), this, TQT_SLOT( setMatch(int) ) );
-	connect( myButtonGroup, TQT_SIGNAL( menuItemSelected(int,int) ), this, TQT_SLOT( thinButtonMenu(int,int) ) );
+  connect( myButtonGroup, TQ_SIGNAL( leftClick(int) ), this, TQ_SLOT( setMatch(int) ) );
+	connect( myButtonGroup, TQ_SIGNAL( menuItemSelected(int,int) ), this, TQ_SLOT( thinButtonMenu(int,int) ) );
 
   myCoreClock.start( 100, FALSE );
   resize();
@@ -85,7 +85,7 @@ void core::createNewIO( int type, int ID, int side, int str )
           internetioPtr = new io_internet( this, myResource );
           myIOMap.add( ID, internetioPtr );
           internetioPtr->setID( ID );
-          connect( internetioPtr, TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( command2Match( const Command& ) ) );
+          connect( internetioPtr, TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( command2Match( const Command& ) ) );
         }
         else
         {
@@ -110,7 +110,7 @@ void core::createNewIO( int type, int ID, int side, int str )
           internetioPtr = new io_internet( this, myResource );
           myIOMap.add( ID, internetioPtr );
           internetioPtr->setID( ID );
-          connect( internetioPtr, TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( command2Match( const Command& ) ) );
+          connect( internetioPtr, TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( command2Match( const Command& ) ) );
         }
         else
         {
@@ -137,7 +137,7 @@ void core::createNewIO( int type, int ID, int side, int str )
 				engineioPtr = new io_engine( this, myResource );
 				myIOMap.add( ID, engineioPtr );
 				engineioPtr->setID( ID );
-				connect( engineioPtr, TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( command2Match( const Command& ) ) );
+				connect( engineioPtr, TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( command2Match( const Command& ) ) );
 				engineioPtr->Start( side );
 				engineioPtr->recvCMD( Command( ID, CMD_Set_Difficulty, TQString().setNum( 1 << str ) ) );
 				break;
@@ -146,7 +146,7 @@ void core::createNewIO( int type, int ID, int side, int str )
 //				ioEmailPtr = new io_email( this, myResource );
 //				myIOMap.add( ID, ioEmailPtr );
 //				ioEmailPtr->setID( ID );
-//				connect( ioEmailPtr, TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( command2Match( const Command& ) ) );
+//				connect( ioEmailPtr, TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( command2Match( const Command& ) ) );
 				break;
     default:
         /* No IO needed */
@@ -180,8 +180,8 @@ match* core::newMatch( match_param* param )
   createNewIO( param->type(BLACK), newID, BLACK, param->strength(BLACK) );
 
   /* Connect Signals */
-  connect( match_ptr, TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( command2IO( const Command& ) ) );
-  connect( &myCoreClock, TQT_SIGNAL( timeout() ), match_ptr, TQT_SLOT( tick() ) );
+  connect( match_ptr, TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( command2IO( const Command& ) ) );
+  connect( &myCoreClock, TQ_SIGNAL( timeout() ), match_ptr, TQ_SLOT( tick() ) );
 
   /* Set this new match as the current match */
   setMatch( newID );
@@ -206,9 +206,9 @@ void core::setMatch( int ID )
   if( currentMatch != NULL )
   {
     currentMatch->setCurrent( FALSE );
-    disconnect( currentMatch, TQT_SIGNAL( setClocks() ), this, TQT_SLOT( slot_setClocks() ) );
-    disconnect( currentMatch, TQT_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQT_SLOT( slot_setStatusBar( const int&, const TQString& ) ) );
-    disconnect( currentMatch, TQT_SIGNAL( setNotation() ), this, TQT_SLOT( slot_setNotation() ) );
+    disconnect( currentMatch, TQ_SIGNAL( setClocks() ), this, TQ_SLOT( slot_setClocks() ) );
+    disconnect( currentMatch, TQ_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQ_SLOT( slot_setStatusBar( const int&, const TQString& ) ) );
+    disconnect( currentMatch, TQ_SIGNAL( setNotation() ), this, TQ_SLOT( slot_setNotation() ) );
     currentMatch->setVisibility( FALSE );
   }
 	/*
@@ -217,9 +217,9 @@ void core::setMatch( int ID )
 	currentMatch = myMatchMap.find( ID );
 	currentMatch->setVisibility( TRUE );
 	myButtonGroup->setButton( ID );
-	connect( currentMatch, TQT_SIGNAL( setClocks() ), this, TQT_SLOT( slot_setClocks() ) );
-	connect( currentMatch, TQT_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQT_SLOT( slot_setStatusBar( const int&, const TQString& ) ) );
-	connect( currentMatch, TQT_SIGNAL( setNotation() ), this, TQT_SLOT( slot_setNotation() ) );
+	connect( currentMatch, TQ_SIGNAL( setClocks() ), this, TQ_SLOT( slot_setClocks() ) );
+	connect( currentMatch, TQ_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQ_SLOT( slot_setStatusBar( const int&, const TQString& ) ) );
+	connect( currentMatch, TQ_SIGNAL( setNotation() ), this, TQ_SLOT( slot_setNotation() ) );
 	currentMatch->setCurrent( TRUE );
 	emit requestResize();
 	emit initMatch();
@@ -622,7 +622,7 @@ bool core::load( const TQString &IncURL )
 {
 	listPGN = new list_pgn( 0, "listPGN" );
 	myResource->tabManager->addTab( listPGN, IncURL.section( '/', -1 ) );
-	connect( listPGN, TQT_SIGNAL( selected( const TQString&, const int& ) ), this, TQT_SLOT( load( const TQString&, const int& ) ) );
+	connect( listPGN, TQ_SIGNAL( selected( const TQString&, const int& ) ), this, TQ_SLOT( load( const TQString&, const int& ) ) );
 	listPGN->setURL( IncURL );
 return TRUE;
 }
@@ -756,7 +756,7 @@ void core::matchMenu( int opt )
 		case MENU_HINT:
 			currentMatch->requestHint();
 			break;
-		/* Qt::Orientation */
+		/* Orientation */
 		case MENU_ORIENTATION:
 			currentMatch->flip();
 			break;
