@@ -49,37 +49,37 @@ dlg_settings::dlg_settings(TQWidget *parent, const char *name, resource *Rsrc )
 														i18n( "Various aspects of Knights get configured here." ),
 														TQPixmap( locate( "data", "knights/icon-general.png" ) ) );
 	PAGE_General = new setPageGeneral( FRAME_General, Resource );
-	connect( PAGE_General, TQT_SIGNAL( enableApply() ), this, TQT_SLOT( slotEnableApply() ) );
+	connect( PAGE_General, TQ_SIGNAL( enableApply() ), this, TQ_SLOT( slotEnableApply() ) );
 
 	/* Display Page */
 	FRAME_Display = addPage(	i18n( "Display" ),
 														i18n( "These settings determine how Knights displays itself to you." ),
 														TQPixmap( locate( "data", "knights/icon-display.png" ) ) );
 	PAGE_Display = new setPageDisplay( FRAME_Display, Resource );
-	connect( PAGE_Display, TQT_SIGNAL( enableApply() ), this, TQT_SLOT( slotEnableApply() ) );
+	connect( PAGE_Display, TQ_SIGNAL( enableApply() ), this, TQ_SLOT( slotEnableApply() ) );
 
 	/* Audio Page */
 	FRAME_Audio = addPage(	i18n( "Audio" ),
 														i18n( "These settings determine what Knights sounds like." ),
 														Resource->LoadIcon( TQString("multimedia"), TDEIcon::Panel ) );
 	PAGE_Audio = new setPageAudio( FRAME_Audio, Resource );
-	connect( PAGE_Audio, TQT_SIGNAL( enableApply() ), this, TQT_SLOT( slotEnableApply() ) );
+	connect( PAGE_Audio, TQ_SIGNAL( enableApply() ), this, TQ_SLOT( slotEnableApply() ) );
 
 	/* Engines Page */
 	FRAME_Engines = addPage(	i18n( "Computer Opponents" ),
 														i18n( "Configure your chess engines here." ),
 														Resource->LoadIcon( TQString("gear"), TDEIcon::Panel ) );
 	PAGE_Engines = new setPageEngines( FRAME_Engines, Resource );
-	connect( PAGE_Engines, TQT_SIGNAL( enableApply() ), this, TQT_SLOT( slotEnableApply() ) );
+	connect( PAGE_Engines, TQ_SIGNAL( enableApply() ), this, TQ_SLOT( slotEnableApply() ) );
 
 	/* Servers Page */
 	FRAME_Servers = addPage(	i18n( "Chess Servers" ),
 														i18n( "Configure your internet chess servers here." ),
 														Resource->LoadIcon( TQString("network"), TDEIcon::Panel ) );
 	PAGE_Servers = new setPageServers( FRAME_Servers, Resource );
-	connect( PAGE_Servers, TQT_SIGNAL( enableApply() ), this, TQT_SLOT( slotEnableApply() ) );
+	connect( PAGE_Servers, TQ_SIGNAL( enableApply() ), this, TQ_SLOT( slotEnableApply() ) );
 
-	connect( this, TQT_SIGNAL( aboutToShowPage( TQWidget* ) ), this, TQT_SLOT( slotPageChanging( TQWidget* ) ) );
+	connect( this, TQ_SIGNAL( aboutToShowPage( TQWidget* ) ), this, TQ_SLOT( slotPageChanging( TQWidget* ) ) );
 
 	/* Init the buttons */
 	showButtonCancel( TRUE );
