@@ -125,8 +125,8 @@ void io_engine::Start( const int side )
 			proto = new proto_xboard( myID );
 			break;
 	}
-	connect( proto, TQT_SIGNAL( output( const TQString& ) ), this, TQT_SLOT( WriteFIFO( const TQString& ) ) );
-	connect( proto, TQT_SIGNAL( output( const Command& ) ), this, TQT_SLOT( recvProtoCMD( const Command& ) ) );
+	connect( proto, TQ_SIGNAL( output( const TQString& ) ), this, TQ_SLOT( WriteFIFO( const TQString& ) ) );
+	connect( proto, TQ_SIGNAL( output( const Command& ) ), this, TQ_SLOT( recvProtoCMD( const Command& ) ) );
 
 	/* ...engine's display name */
 	proto->parse( Command( myID, CMD_Set_Name, (*IT).Name ) );
@@ -156,9 +156,9 @@ void io_engine::Start( const int side )
 		kdError() << "io_engine::Start: Can not run the engine: " << (*IT).Filename << endl;
 		return;
 	}
-	connect( engine, TQT_SIGNAL( wroteStdin( TDEProcess* ) ), this, TQT_SLOT( SendClear( TDEProcess* ) ) );
-	connect( engine, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQT_SLOT( Recv( TDEProcess*, char*, int ) ) );
-	connect( engine, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), this, TQT_SLOT( Recv( TDEProcess*, char*, int ) ) );
+	connect( engine, TQ_SIGNAL( wroteStdin( TDEProcess* ) ), this, TQ_SLOT( SendClear( TDEProcess* ) ) );
+	connect( engine, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQ_SLOT( Recv( TDEProcess*, char*, int ) ) );
+	connect( engine, TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), this, TQ_SLOT( Recv( TDEProcess*, char*, int ) ) );
 
 	proto->parse( Command( myID, CMD_Init ) );
 
