@@ -65,9 +65,9 @@ io_internet::io_internet( TQWidget *parent, resource *rsrc )
 
   /* create the login dialog and show it to the user */
   loginDlg = new dlg_login( myParent, "LoginDialog", myResource);
-  connect(loginDlg, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( connectToServer() ) );
-  connect(loginDlg, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( selfDestruct() ) );
-	connect(loginDlg, TQT_SIGNAL( login(TQString, TQString) ), this, TQT_SLOT( setUserInfo(TQString, TQString) ) );
+  connect(loginDlg, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( connectToServer() ) );
+  connect(loginDlg, TQ_SIGNAL( cancelClicked() ), this, TQ_SLOT( selfDestruct() ) );
+	connect(loginDlg, TQ_SIGNAL( login(TQString, TQString) ), this, TQ_SLOT( setUserInfo(TQString, TQString) ) );
 }
 
 ///////////////////////////////////////////////////////////
@@ -105,7 +105,7 @@ io_internet::~io_internet()
   {
     if(myResource->tabManager->isTab(*i))
     {
-      myResource->tabManager->removeTab(TQT_TQOBJECT(*i));
+      myResource->tabManager->removeTab(*i);
     }
   }
 }
@@ -201,11 +201,11 @@ void io_internet::connectToServer()
   socket->enableWrite(true);
 
   /* connect a signal to readReady */
-  connect(socket, TQT_SIGNAL(readEvent(TDESocket *)), this, TQT_SLOT(readCommand(TDESocket *)));
+  connect(socket, TQ_SIGNAL(readEvent(TDESocket *)), this, TQ_SLOT(readCommand(TDESocket *)));
 
   /* setup the seekTimer and turn it off by default */
   seekTimer = new TQTimer(this);
-  connect(seekTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(processSeekTimer()));
+  connect(seekTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(processSeekTimer()));
 
   /* succesfully connected to the server, turn connected on and flush the command buffer */
   connected = true;
@@ -224,20 +224,20 @@ void io_internet::connectToServer()
 	consoleTab = new Console( 0, myServer->Name.utf8(), myResource );
 	myTabList[consoleTab] = consoleTab;
 	myResource->tabManager->addTab( myTabList[consoleTab], i18n( "%1 Console" ).arg( myServer->Name ) );
-  connect( myTabList[consoleTab], TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( recvCMD( const Command& ) ) );
-	connect( this, TQT_SIGNAL( sendCMD( const Command& ) ), myTabList[consoleTab], TQT_SLOT( recvCMD( const Command& ) ) );
+  connect( myTabList[consoleTab], TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( recvCMD( const Command& ) ) );
+	connect( this, TQ_SIGNAL( sendCMD( const Command& ) ), myTabList[consoleTab], TQ_SLOT( recvCMD( const Command& ) ) );
 
 	tempTab = new tab_SeekList( 0, "seekList", myResource );
 	myTabList[tempTab] = tempTab;
 	myResource->tabManager->addTab( myTabList[tempTab], i18n( "Sought Matches List" ) );
-  connect( myTabList[tempTab], TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( recvCMD( const Command& ) ) );
-	connect( this, TQT_SIGNAL( sendCMD( const Command& ) ), myTabList[tempTab], TQT_SLOT( recvCMD( const Command& ) ) );
+  connect( myTabList[tempTab], TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( recvCMD( const Command& ) ) );
+	connect( this, TQ_SIGNAL( sendCMD( const Command& ) ), myTabList[tempTab], TQ_SLOT( recvCMD( const Command& ) ) );
 
 	tempTab = new Challenge_Graph( 0, "seekGraph", myResource );
 	myTabList[tempTab] = tempTab;
 	myResource->tabManager->addTab( myTabList[tempTab], i18n( "Sought Matches Graph" ) );
-  connect( myTabList[tempTab], TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( recvCMD( const Command& ) ) );
-	connect( this, TQT_SIGNAL( sendCMD( const Command& ) ), myTabList[tempTab], TQT_SLOT( recvCMD( const Command& ) ) );
+  connect( myTabList[tempTab], TQ_SIGNAL( sendCMD( const Command& ) ), this, TQ_SLOT( recvCMD( const Command& ) ) );
+	connect( this, TQ_SIGNAL( sendCMD( const Command& ) ), myTabList[tempTab], TQ_SLOT( recvCMD( const Command& ) ) );
 
 	myResource->tabManager->showTab(consoleTab);
 
@@ -474,9 +474,9 @@ void io_internet::parseLoginData( TQString data )
     {
       loginDlg = new dlg_login( myParent, "LoginDialog", myResource);
 			loginDlg->disableServerSelect();
-		  connect(loginDlg, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( sendUserName() ) );
-		  connect(loginDlg, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( selfDestruct() ) );
-			connect(loginDlg, TQT_SIGNAL( login(TQString, TQString) ), this, TQT_SLOT( setUserInfo(TQString, TQString) ) );
+		  connect(loginDlg, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( sendUserName() ) );
+		  connect(loginDlg, TQ_SIGNAL( cancelClicked() ), this, TQ_SLOT( selfDestruct() ) );
+			connect(loginDlg, TQ_SIGNAL( login(TQString, TQString) ), this, TQ_SLOT( setUserInfo(TQString, TQString) ) );
     }
     else if(data.contains("Press return to enter the server as"))
     {
@@ -540,9 +540,9 @@ void io_internet::parseLine( TQString line )
           delete challenge;
         }
         challenge = new dlg_challenge( 0, "Challenge", myResource );
-        connect( challenge, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( nullifyChallenge() ) );
-        connect( challenge, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT( acceptChallenge() ) );
-        connect( challenge, TQT_SIGNAL( user2Clicked() ), this, TQT_SLOT( declineChallenge() ) );
+        connect( challenge, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( nullifyChallenge() ) );
+        connect( challenge, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT( acceptChallenge() ) );
+        connect( challenge, TQ_SIGNAL( user2Clicked() ), this, TQ_SLOT( declineChallenge() ) );
         line.replace(TQRegExp("^\\s*Challenge: "), "");
         challenge->setValues( line, userName );
         parseMode = CHALLENGE_MODE;
