@@ -29,7 +29,7 @@
 #include <tdeaboutdata.h>
 #include <kstatusbar.h>
 #include <tdecmdlineargs.h>
-/* QT */
+/* TQT */
 #include <tqlayout.h>
 #include <tqwidget.h>
 #include <tqpixmap.h>
@@ -56,7 +56,7 @@ class splash;
 **/
 class Knights : public TDEMainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
 		TDEAboutData			*aboutData;
