@@ -38,7 +38,7 @@ list_pgn::list_pgn(TQWidget *parent, const char *name) : TQVBox(parent,name)
 	listView->setShowSortIndicator( TRUE );
 	listView->restoreLayout( kapp->config(), "PGN_ListView" );
 	listView->show();
-	connect( listView, TQT_SIGNAL( executed( TQListViewItem* ) ), this, TQT_SLOT( slot_selected( TQListViewItem* ) ) );
+	connect( listView, TQ_SIGNAL( executed( TQListViewItem* ) ), this, TQ_SLOT( slot_selected( TQListViewItem* ) ) );
 
 	/*
 			Showing listView while scanning can mean the difference between
@@ -126,7 +126,7 @@ void list_pgn::timerEvent( TQTimerEvent* )
 		{
 			emit selected( myURL, 0 );
 		}
-		TQT_TQOBJECT(this)->killTimers();
+		this->killTimers();
 		listView->show();
 		dummyView->hide();
 	}
