@@ -39,8 +39,8 @@ match::match( TQWidget *parent, match_param *param, resource *Rsrc ) : TQWidget(
 	Logic = new logic( Resource, param );
 	Board = new board_2d( parent, "Board", Resource, Logic );
 	Board->show();
-	connect( Board, TQT_SIGNAL( leftClick(int) ), this, TQT_SLOT( slot_Select(int) ) );
-	connect( Board, TQT_SIGNAL( rightClick(int) ), this, TQT_SLOT( slot_Preview(int) ) );
+	connect( Board, TQ_SIGNAL( leftClick(int) ), this, TQ_SLOT( slot_Select(int) ) );
+	connect( Board, TQ_SIGNAL( rightClick(int) ), this, TQ_SLOT( slot_Preview(int) ) );
 	Clock = new chessclock( this, "Clock", Resource );
 	Record->init();
 	Logic->Init();
@@ -63,11 +63,11 @@ match::match( TQWidget *parent, match_param *param, resource *Rsrc ) : TQWidget(
 	parseMatchParam();
 
 	/* Connect Signals and Slots */
-	connect( param, TQT_SIGNAL( valuesChanged() ), this, TQT_SLOT( parseMatchParam() ) );
-	connect( Record, TQT_SIGNAL( processMove(ChessMove) ), this, TQT_SLOT( move(ChessMove) ) );
-	connect( Record, TQT_SIGNAL( processSpecial() ), this, TQT_SLOT( loadSpecial() ) );
-	connect( Clock, TQT_SIGNAL( flagFell(const bool) ), this, TQT_SLOT( slot_flagFell(const bool) ) );
-	connect( this, TQT_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQT_SLOT( saveStatusBar( const int&, const TQString& ) ) );
+	connect( param, TQ_SIGNAL( valuesChanged() ), this, TQ_SLOT( parseMatchParam() ) );
+	connect( Record, TQ_SIGNAL( processMove(ChessMove) ), this, TQ_SLOT( move(ChessMove) ) );
+	connect( Record, TQ_SIGNAL( processSpecial() ), this, TQ_SLOT( loadSpecial() ) );
+	connect( Clock, TQ_SIGNAL( flagFell(const bool) ), this, TQ_SLOT( slot_flagFell(const bool) ) );
+	connect( this, TQ_SIGNAL( setStatusBar( const int&, const TQString& ) ), this, TQ_SLOT( saveStatusBar( const int&, const TQString& ) ) );
 
 }
 ///////////////////////////////////////
@@ -172,7 +172,7 @@ void match::tick(void)
 void match::clearSelections( void )
 {
 	bool commitFlag( FALSE );
-	register char tmp;
+	char tmp;
 
 	if( ICSGameMode == Null )
 	{
@@ -386,7 +386,7 @@ TQString match::clock( const bool Army )
 void match::slot_Select( int position )
 {
 	bool preMoving(FALSE);
-	register char tmp, army, selected(Null);
+	char tmp, army, selected(Null);
 
 	if( Paused ) return;
 	/* Clear all non-SELECT notes */
