@@ -70,18 +70,18 @@ void setPageDisplay::initTab1( void )
 	Tab1->setMargin( margin );
 	BOX_Themes = new TQHBox( Tab1 );
 	GROUP_Boards = new TQGroupBox( 1,
-																Qt::Vertical,
+																TQt::Vertical,
 																i18n( "Board Themes" ),
 																BOX_Themes );
 	Current_Boards = new KComboBox ( GROUP_Boards );
 	GROUP_Chessmen = new TQGroupBox( 1,
-																Qt::Vertical,
+																TQt::Vertical,
 																i18n( "Chessman Themes" ),
 																BOX_Themes );
 	Current_Chessmen = new KComboBox ( GROUP_Chessmen );
 	
 	GROUP_Theme_Size = new TQGroupBox( 3,
-																Qt::Horizontal,
+																TQt::Horizontal,
 																i18n( "Theme Size" ),
 																Tab1 );
 	
@@ -90,63 +90,63 @@ void setPageDisplay::initTab1( void )
 																			14,
 																			2,
 																			( Resource->ThemeSize - IMAGE_MIN ) / 8 ,
-																			Qt::Horizontal,
+																			TQt::Horizontal,
 																			GROUP_Theme_Size );
 	Size_Max = new TQLabel( i18n( "Large" ), GROUP_Theme_Size );
 	
-	GROUP_SCID_Images = new TQGroupBox( 2, Qt::Horizontal, i18n("Player Images File:"), Tab1 );
+	GROUP_SCID_Images = new TQGroupBox( 2, TQt::Horizontal, i18n("Player Images File:"), Tab1 );
 	EDIT_SCID_Images = new KLineEdit( GROUP_SCID_Images );
 	EDIT_SCID_Images->setText( Resource->SCID_Image_Path );
-	connect( EDIT_SCID_Images, TQT_SIGNAL( textChanged(const TQString&) ), this, TQT_SLOT( slot_SCID_Images(const TQString&) ) );
+	connect( EDIT_SCID_Images, TQ_SIGNAL( textChanged(const TQString&) ), this, TQ_SLOT( slot_SCID_Images(const TQString&) ) );
 	BUTTON_SCID_Images = new TQPushButton( GROUP_SCID_Images );
 	BUTTON_SCID_Images->setPixmap( Resource->LoadIcon( TQString( "document-open" ), TDEIcon::Toolbar ) );
-	connect( BUTTON_SCID_Images, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_SCID_Images_Button() ) );
+	connect( BUTTON_SCID_Images, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_SCID_Images_Button() ) );
 
 	GROUP_General_Graphics = new TQGroupBox( 4,
-																Qt::Vertical,
+																TQt::Vertical,
 																i18n( "Other Display Options" ),
 																Tab1 );
 
 	Board_Orientation = new TQCheckBox( i18n( "Reverse Board Orientation" ), GROUP_General_Graphics );
 	Board_Orientation->setChecked( Resource->OPTION_Board_Orientation );
-	connect(	Board_Orientation, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Board_Orientation(bool) ) );
+	connect(	Board_Orientation, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Board_Orientation(bool) ) );
 
 	Show_Splashscreen = new TQCheckBox( i18n( "Display Startup Logo" ), GROUP_General_Graphics );
 	Show_Splashscreen->setChecked( Resource->OPTION_Show_Splash );
-	connect(	Show_Splashscreen, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Splashscreen(bool) ) );
+	connect(	Show_Splashscreen, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Splashscreen(bool) ) );
 
 	Auto_Preview = new TQCheckBox( i18n( "Automatic Preview" ), GROUP_General_Graphics );
 	Auto_Preview->setChecked( Resource->OPTION_Auto_Preview );
-	connect(	Auto_Preview, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Auto_Preview(bool) ) );
+	connect(	Auto_Preview, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Auto_Preview(bool) ) );
 
 	Show_Last_Move = new TQCheckBox( i18n( "Show Last Move" ), GROUP_General_Graphics );
 	Show_Last_Move->setChecked( Resource->OPTION_Show_Last_Move );
-	connect(	Show_Last_Move, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Show_Last_Move(bool) ) );
+	connect(	Show_Last_Move, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Show_Last_Move(bool) ) );
 
 	Animate_Move = new TQCheckBox( i18n( "Animate Moves" ), GROUP_General_Graphics );
 	Animate_Move->setChecked( Resource->OPTION_Animate_Moves );
-	connect(	Animate_Move, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Animate_Move(bool) ) );
+	connect(	Animate_Move, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Animate_Move(bool) ) );
 
 	Show_Coord = new TQCheckBox( i18n( "Show Coordinates" ), GROUP_General_Graphics );
 	Show_Coord->setChecked( Resource->OPTION_Show_Coord );
-	connect(	Show_Coord, TQT_SIGNAL( toggled(bool) ),
-						this, TQT_SLOT( slotToggle_Show_Coord(bool) ) );
+	connect(	Show_Coord, TQ_SIGNAL( toggled(bool) ),
+						this, TQ_SLOT( slotToggle_Show_Coord(bool) ) );
 
 	Current_Theme_Size->setTickmarks( TQSlider::Below );
 	Current_Boards->setEditable( FALSE );
 	Current_Chessmen->setEditable( FALSE );
 	buildThemeList();
-	connect(	Current_Boards, TQT_SIGNAL( activated(int) ),
-						this, TQT_SLOT( slotCurrent_Boards(int) ) );
-	connect(	Current_Chessmen, TQT_SIGNAL( activated(int) ),
-						this, TQT_SLOT( slotCurrent_Chessmen(int) ) );
-	connect(	Current_Theme_Size, TQT_SIGNAL( valueChanged(int) ),
-						this, TQT_SLOT( slotCurrent_Theme_Size(int) ) );
+	connect(	Current_Boards, TQ_SIGNAL( activated(int) ),
+						this, TQ_SLOT( slotCurrent_Boards(int) ) );
+	connect(	Current_Chessmen, TQ_SIGNAL( activated(int) ),
+						this, TQ_SLOT( slotCurrent_Chessmen(int) ) );
+	connect(	Current_Theme_Size, TQ_SIGNAL( valueChanged(int) ),
+						this, TQ_SLOT( slotCurrent_Theme_Size(int) ) );
 	TabParent->addTab( Tab1, i18n("General") );
 }
 ///////////////////////////////////////
@@ -167,66 +167,66 @@ void setPageDisplay::initTab2( void )
 		GRID_Style->addMultiCellWidget( Console_Sample, 5, 10, 1, 1 );
 
 		Default_Button = new TQPushButton( i18n("Restore Defaults"), Tab2 );
-		connect( Default_Button, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_setDefault() ) );
+		connect( Default_Button, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_setDefault() ) );
 		GRID_Style->addWidget( Default_Button, 11, 1 );
 
 		Fonts_Button_Standard = new TQPushButton( i18n("Standard Font..."), Tab2 );
-		connect( Fonts_Button_Standard, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_Standard() ) );
+		connect( Fonts_Button_Standard, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_Standard() ) );
 		GRID_Style->addWidget( Fonts_Button_Standard, 5, 3 );
 
 		Colors_Button_Standard = new TQPushButton( Tab2 );
 		Colors_Button_Standard->setPixmap( ColorsIcon );
-		connect( Colors_Button_Standard, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_Standard() ) );
+		connect( Colors_Button_Standard, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_Standard() ) );
 		GRID_Style->addWidget( Colors_Button_Standard, 5, 5 );
 
 		Fonts_Button_PrivateTell = new TQPushButton( i18n("Private Font..."), Tab2 );
-		connect( Fonts_Button_PrivateTell, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_PrivateTell() ) );
+		connect( Fonts_Button_PrivateTell, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_PrivateTell() ) );
 		GRID_Style->addWidget( Fonts_Button_PrivateTell, 6, 3 );
 
 		Colors_Button_PrivateTell = new TQPushButton( Tab2 );
 		Colors_Button_PrivateTell->setPixmap( ColorsIcon );
-		connect( Colors_Button_PrivateTell, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_PrivateTell() ) );
+		connect( Colors_Button_PrivateTell, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_PrivateTell() ) );
 		GRID_Style->addWidget( Colors_Button_PrivateTell, 6, 5 );
 
 		Fonts_Button_ChannelTell = new TQPushButton( i18n("Channel Font..."), Tab2 );
-		connect( Fonts_Button_ChannelTell, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_ChannelTell() ) );
+		connect( Fonts_Button_ChannelTell, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_ChannelTell() ) );
 		GRID_Style->addWidget( Fonts_Button_ChannelTell, 7, 3 );
 
 		Colors_Button_ChannelTell = new TQPushButton( Tab2 );
 		Colors_Button_ChannelTell->setPixmap( ColorsIcon );
-		connect( Colors_Button_ChannelTell, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_ChannelTell() ) );
+		connect( Colors_Button_ChannelTell, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_ChannelTell() ) );
 		GRID_Style->addWidget( Colors_Button_ChannelTell, 7, 5 );
 
 		Fonts_Button_Shout = new TQPushButton( i18n("Shout Font..."), Tab2 );
-		connect( Fonts_Button_Shout, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_Shout() ) );
+		connect( Fonts_Button_Shout, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_Shout() ) );
 		GRID_Style->addWidget( Fonts_Button_Shout, 8, 3 );
 
 		Colors_Button_Shout = new TQPushButton( Tab2 );
 		Colors_Button_Shout->setPixmap( ColorsIcon );
-		connect( Colors_Button_Shout, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_Shout() ) );
+		connect( Colors_Button_Shout, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_Shout() ) );
 		GRID_Style->addWidget( Colors_Button_Shout, 8, 5 );
 
 		Fonts_Button_Whisper = new TQPushButton( i18n("Whisper Font..."), Tab2 );
-		connect( Fonts_Button_Whisper, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_Whisper() ) );
+		connect( Fonts_Button_Whisper, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_Whisper() ) );
 		GRID_Style->addWidget( Fonts_Button_Whisper, 9, 3 );
 
 		Colors_Button_Whisper = new TQPushButton( Tab2 );
 		Colors_Button_Whisper->setPixmap( ColorsIcon );
-		connect( Colors_Button_Whisper, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_Whisper() ) );
+		connect( Colors_Button_Whisper, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_Whisper() ) );
 		GRID_Style->addWidget( Colors_Button_Whisper, 9, 5 );
 
 		Fonts_Button_Notification = new TQPushButton( i18n("Notification Font..."), Tab2 );
-		connect( Fonts_Button_Notification, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Font_Notification() ) );
+		connect( Fonts_Button_Notification, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Font_Notification() ) );
 		GRID_Style->addWidget( Fonts_Button_Notification, 10, 3 );
 
 		Colors_Button_Notification = new TQPushButton( Tab2 );
 		Colors_Button_Notification->setPixmap( ColorsIcon );
-		connect( Colors_Button_Notification, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_Notification() ) );
+		connect( Colors_Button_Notification, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_Notification() ) );
 		GRID_Style->addWidget( Colors_Button_Notification, 10, 5 );
 
 		Colors_Button_Background = new TQPushButton( Tab2 );
 		Colors_Button_Background->setPixmap( ColorsIcon );
-		connect( Colors_Button_Background, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_Color_Background() ) );
+		connect( Colors_Button_Background, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slot_Color_Background() ) );
 		GRID_Style->addWidget( Colors_Button_Background, 11, 5 );
 
 	resetSampleConsole();
