@@ -37,23 +37,23 @@ tab_SeekList::tab_SeekList(TQWidget *parent, const char *name, resource *Rsrc )
 
 	menuSeek = new TDEPopupMenu( this );
 	menuSeek->setCheckable( TRUE );
-	menuSeek->insertItem( i18n("Seek Matches"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_SEEK );
+	menuSeek->insertItem( i18n("Seek Matches"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_SEEK );
 	menuSeek->insertSeparator();
-	menuSeek->insertItem( i18n("Accept This Match"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_ACCEPT_MATCH );
-	menuSeek->insertItem( i18n("Tell..."), this, TQT_SLOT( menuFunct(int) ), 0, MENU_TELL );
-	menuSeek->insertItem( i18n("Assess..."), this, TQT_SLOT( menuFunct(int) ), 0, MENU_ASSESS );
-	menuSeek->insertItem( i18n("Player Info"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_FINGER );
+	menuSeek->insertItem( i18n("Accept This Match"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_ACCEPT_MATCH );
+	menuSeek->insertItem( i18n("Tell..."), this, TQ_SLOT( menuFunct(int) ), 0, MENU_TELL );
+	menuSeek->insertItem( i18n("Assess..."), this, TQ_SLOT( menuFunct(int) ), 0, MENU_ASSESS );
+	menuSeek->insertItem( i18n("Player Info"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_FINGER );
 	menuSeek->insertItem( TQIconSet( myResource->LoadIcon( TQString("history"), TDEIcon::Small ) ),
-												i18n("Player History"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_HISTORY );
+												i18n("Player History"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_HISTORY );
 	menuSeek->insertSeparator();
-	menuSeek->insertItem( i18n("Add to Friends"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_NOTIFY );
-	menuSeek->insertItem( i18n("Ignore This Player"), this, TQT_SLOT( menuFunct(int) ), 0, MENU_CENSOR );
+	menuSeek->insertItem( i18n("Add to Friends"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_NOTIFY );
+	menuSeek->insertItem( i18n("Ignore This Player"), this, TQ_SLOT( menuFunct(int) ), 0, MENU_CENSOR );
 	menuSeek->setItemChecked( MENU_SEEK, FALSE );
 
-	connect( this, TQT_SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int ) ),
-						this, TQT_SLOT( display_menuSeek( TQListViewItem*, const TQPoint&, int ) ) );
-	connect( this, TQT_SIGNAL( executed( TQListViewItem* ) ),
-						this, TQT_SLOT( selectMatch( TQListViewItem* ) ) );
+	connect( this, TQ_SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int ) ),
+						this, TQ_SLOT( display_menuSeek( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( this, TQ_SIGNAL( executed( TQListViewItem* ) ),
+						this, TQ_SLOT( selectMatch( TQListViewItem* ) ) );
 }
 tab_SeekList::~tab_SeekList()
 {
