@@ -33,7 +33,7 @@ class resource;
 
 class TabManager : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 								TabManager( resource *rsrc );
