@@ -50,7 +50,7 @@ wiz_setup::wiz_setup(TQWidget *parent, const char *name, resource *Rsrc ) : KWiz
 	initPage5();
 	setCaption( i18n( "Knights Setup Wizard" ) );
 
-	connect( this, TQT_SIGNAL( selected(const TQString&) ), this, TQT_SLOT( slot_Work(const TQString&) ) );
+	connect( this, TQ_SIGNAL( selected(const TQString&) ), this, TQ_SLOT( slot_Work(const TQString&) ) );
 }
 wiz_setup::~wiz_setup()
 {
@@ -97,7 +97,7 @@ void wiz_setup::initPage2( void )
 	pgnExplain->setText( i18n( "When Knights saves a match to disk, it uses Portable Game Notation (PGN) to store the match. Several other computer chess games use PGN too. If you like, Knights can be the default PGN viewer on this system." ) );
 	P2B1->addWidget( pgnExplain, 1, 3 );
 
-	pgnButtons = new TQButtonGroup( 2, Qt::Vertical, i18n( "Let Knights handle PGN files?" ), Page2 );
+	pgnButtons = new TQButtonGroup( 2, TQt::Vertical, i18n( "Let Knights handle PGN files?" ), Page2 );
 		pgnYes = new TQRadioButton( i18n( "Yes" ), pgnButtons );
 		pgnNo = new TQRadioButton( i18n( "No" ), pgnButtons );
 	pgnButtons->setButton( 0 );
@@ -125,7 +125,7 @@ void wiz_setup::initPage3( void )
 	engineExplain->setText( i18n( "Knights can not play a chess match against you without help. Known as Chess Engines, these helpers can be found on the Internet and are often included with your distribution. Knights can look for Chess Engines that you may already have. If found, Knights will configure itself to use them." ) );
 	P3B1->addWidget( engineExplain, 1, 3 );
 
-	engineButtons = new TQButtonGroup( 2, Qt::Vertical, i18n( "Let Knights search for chess engines?" ), Page3 );
+	engineButtons = new TQButtonGroup( 2, TQt::Vertical, i18n( "Let Knights search for chess engines?" ), Page3 );
 		engineYes = new TQRadioButton( i18n( "Yes" ), engineButtons );
 		engineNo = new TQRadioButton( i18n( "No" ), engineButtons );
 	engineButtons->setButton( 0 );
@@ -153,7 +153,7 @@ void wiz_setup::initPage4( void )
 	serverExplain->setText( i18n( "In order for you to play chess online, Knights will have to connect to a chess server. Knights has a list of several of these servers. If you like, this list can be used to automatically configure Knights." ) );
 	P4B1->addWidget( serverExplain, 1, 3 );
 
-	serverButtons = new TQButtonGroup( 2, Qt::Vertical, i18n( "Let Knights configure chess servers?" ), Page4 );
+	serverButtons = new TQButtonGroup( 2, TQt::Vertical, i18n( "Let Knights configure chess servers?" ), Page4 );
 		serverYes = new TQRadioButton( i18n( "Yes" ), serverButtons );
 		serverNo = new TQRadioButton( i18n( "No" ), serverButtons );
 	serverButtons->setButton( 0 );
@@ -210,14 +210,14 @@ void wiz_setup::initPage6( void )
 	licenseText.append( "</K_STD>" );
 	licenseView->setText( licenseText );
 
-	licenseButtons = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Do you accept the terms of our license?" ), Page6 );
+	licenseButtons = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Do you accept the terms of our license?" ), Page6 );
 		licenseYes = new TQRadioButton( i18n( "Yes" ), licenseButtons );
 		licenseNo = new TQRadioButton( i18n( "No" ), licenseButtons );
 	licenseButtons->setButton( 1 );
 
 	addPage( Page6, i18n("Please read and accept our license:") );
 	setHelpEnabled( Page6, FALSE );
-	connect( licenseButtons, TQT_SIGNAL( clicked(int) ), this, TQT_SLOT( slot_License(int) ) );
+	connect( licenseButtons, TQ_SIGNAL( clicked(int) ), this, TQ_SLOT( slot_License(int) ) );
 }
 ///////////////////////////////////////
 //
